Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Application Auto Scaling.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for Application Auto Scaling - AWS Identity and Access Management

# Actions, resources, and condition keys for Application Auto Scaling

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_applicationautoscaling.html .

Application Auto Scaling (service prefix: `application-autoscaling` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by Application Auto Scaling
- Resource types defined by Application Auto Scaling
- Condition keys for Application Auto Scaling

## Actions defined by Application Auto Scaling

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
DeleteScalingPolicy | Deletes an Application Auto Scaling scaling policy that was previously created. | Write |  |  |
DeleteScheduledAction | Deletes an Application Auto Scaling scheduled action that was previously created. | Write |  |  |
DeregisterScalableTarget | Deregisters a scalable target that was previously registered. | Write |  |  |
DescribeScalableTargets | Provides descriptive information for scalable targets with a specified service namespace. | Read |  |  |
DescribeScalingActivities | Provides descriptive information for scaling activities with a specified service namespace for the previous six weeks. | Read |  |  |
DescribeScalingPolicies | Provides descriptive information for scaling policies with a specified service namespace. | Read |  |  |
DescribeScheduledActions | Provides descriptive information for scheduled actions with a specified service namespace. | Read |  |  |
PutScalingPolicy | Creates or updates a policy for an existing Application Auto Scaling scalable target. | Write |  |  |
PutScheduledAction | Creates or updates a scheduled action for an existing Application Auto Scaling scalable target. | Write |  |  |
RegisterScalableTarget | Registers or updates a scalable target. A scalable target is a resource that can be scaled out or in with Application Auto Scaling. | Write |  |  |

## Resource types defined by Application Auto Scaling

Application Auto Scaling does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Application Auto Scaling, specify `“Resource”: “*”` in your policy.

## Condition keys for Application Auto Scaling

Application Auto Scaling has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available keys for conditions .

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.